@@ -13,6 +13,7 @@ from git import Repo
 import logging
 import re
 from urllib.parse import urlparse
+from prettytable import PrettyTable
 
 
 # yaml 数据模型
@@ -960,6 +961,20 @@ def release_branch(module_list, tag_path, c_path, f_branch):
     return merge_result
 
 
+def printTable(list, info):
+    error_table = PrettyTable("编号", "组件名", "分支", "错误信息")
+    for index in range(0, len(list) - 1):
+        model = list[index]
+        error_table.add_row(index, model.module, model.branch, model.msg)
+    error_table.align[1] = '1'
+    error_table.border = True
+    error_table.junction_char = '+'
+    error_table.horizontal_char = '——'
+    error_table.vertical_char = '|'
+    debugInfo(error_table)
+    debugInfo("[!] 以上是{0}".format(info))
+
+
 # 创建分支的对象
 # branch 组件新分支名字
 class yhgit:
@@ -1100,21 +1115,31 @@ class yhgit:
             error_module = "检查失败的模块: \n\n"
             fail_module = "有代码要提交的模块: \n\n"
             succ_module = "没有代码要提交的模块: \n\n"
+            error_list = []
+            fail_list = []
+            success_list = []
             for merg_Model in status_result:
                 if merg_Model.result == 1:
                     succ_module = succ_module + (merg_Model.module + " 分支: " + str(merg_Model.branch) + "\n")
+                    success_list.append(merg_Model)
                 elif merg_Model.result == 0:
                     fail_module = fail_module + (
                             merg_Model.module + " 分支: " + str(merg_Model.branch) + "\n" + " 修改信息: \n" + str(
                         merg_Model.msg) + "\n\n")
+                    fail_list.append(merg_Model)
                 elif merg_Model.result == -1:
                     error_module = error_module + (merg_Model.module + "\n")
-            logging.info(fail_module)
-            logging.info(succ_module)
-            logging.info(error_module)
-            print(fail_module)
-            print(succ_module)
-            print(error_module)
+                    error_list.append(merg_Model)
+
+            printTable(success_list, "没有代码要提交的模块")
+            printTable(fail_list, "有代码要提交的模块")
+            printTable(error_module, "检查失败的模块")
+            # logging.info(fail_module)
+            # logging.info(succ_module)
+            # logging.info(error_module)
+            # print(fail_module)
+            # print(succ_module)
+            # print(error_module)
 
     # 自动提交本地修改的内容
     def commit(self, msg):
